package com.vetti.hotake.mapper;

import java.util.List;
import com.vetti.hotake.domain.HotakeCandidateCompliance;

public interface HotakeCandidateComplianceMapper
{
    public HotakeCandidateCompliance selectHotakeCandidateComplianceById(Long id);

    public List<HotakeCandidateCompliance> selectHotakeCandidateComplianceList(HotakeCandidateCompliance hotakeCandidateCompliance);

    public int insertHotakeCandidateCompliance(HotakeCandidateCompliance hotakeCandidateCompliance);

    public int updateHotakeCandidateCompliance(HotakeCandidateCompliance hotakeCandidateCompliance);

    public int deleteHotakeCandidateComplianceById(Long id);

    public int deleteHotakeCandidateComplianceByIds(Long[] ids);
}

